@rem  Licensed Materials - Property of IBM
@rem  5724-M24
@rem  Copyright IBM Corporation 2007, 2011. All Rights Reserved.
@rem  US Government Users Restricted Rights- Use, duplication or disclosure
@rem  restricted by GSA ADP Schedule Contract with IBM Corp.
@@REM
@@REM  
@@REM
@echo off

setlocal

@@REM echo.
@@REM echo Start Monitor Verification Test
@@REM echo.


GOTO Variables
@REM #######################################################
@REM #                                                     #
@REM # IVT Usage                                           #
@REM #                                                     #
@REM #######################################################
:USAGE
  echo.
  echo  ivt -c ^<component directory^> -d ^<ivt directory^> -f ^<testcase file^> 
  echo      -m ^<test mode^> -o ^<output xml^> -p ^<password^> -s ^<server name^> 
  echo      -t ^<profile typ^> -u ^<user name^> -w ^<profile directory^> -n ^<modelDir^>
  echo.
  echo  where:  
  echo.
  echo   -c  ^<component directory^>:
  echo       which component to run under ivt. If not selected all components 
  echo       will be included
  echo.
  echo   -d  ^<ivt directory^>:
  echo       ivt home directory. By default it is ^<WAS_HOME^>/firststeps.wbm/ivt
  echo.
  echo   -f  ^<testcase file^>:
  echo       which testcase to run under selected component. If not selected all
  echo       testcase files will be run
  echo.
  echo   -m  ^<test mode^>:
  echo       test mode: 0-9. For selected testcase files only last number in file
  echo       name equals or above test mode will run. 0: IVU only; 9: run all tests
  echo.
  echo   -n  ^<model Directory^>:
  echo       directory relative to ^<WAS_HOME^>/firststeps.wbm/ivt/models where the
  echo       files for a specific model install are located.
  echo.
  echo   -o  ^<output format^>
  echo       output file name for xml format: by default test result only goes to stdout.
  echo.
  echo   -s  ^<server name^>:
  echo       WAS server name. default server1
  echo.
  echo   -u  ^<user name^>: WAS user id
  echo.
  echo   -p  ^<password^>: WAS user password
  echo.
  echo   -t  ^<profile typ^>:
  echo       profile type. 1: application server, 2: deployment manager
  echo                     3: none, 4: custom
  echo.
  echo   -w  ^<profile directory^>:
  echo       WAS profile directory. If not provided will assume ../.. 
  echo.
  GOTO DONE

@REM #######################################################
@REM #                                                     #
@REM # Variables                                           #
@REM #                                                     #
@REM #######################################################
:Variables

set runDir=.
set runFile=NULL
set ivtHome=""
set testMode=5
set modelDir=NULL
set profileDir=""
set serverName=server1
set xmlFileName=NULL
set userId=""
set password=""
set tmpFile=ivt_tmp
set profileType=1
set checkWAS=false


@REM #######################################################
@REM #                                                     #
@REM # Read command line options                           #
@REM #                                                     #
@REM #######################################################
:Loop
IF "%1" == "" GOTO Continue
IF "%1" == "-c" (
  set runDir=%2
  GOTO Forward
)
IF "%1" == "-d" (
  set ivtHome=%2
  GOTO Forward
)
IF "%1" == "-f" (
  set runFile=%2
  GOTO Forward
)
IF "%1" == "-m" (
  set testMode=%2
  GOTO Forward
)
IF "%1" == "-n" (
  set modelDir=%2
  GOTO Forward
)
IF "%1" == "-o" (
  set xmlFileName=%2
  GOTO Forward
)
IF "%1" == "-p" (
  set password=%2
  GOTO Forward
)
IF "%1" == "-s" (
  set serverName=%2
  GOTO Forward
)
IF "%1" == "-t" (
  set profileType=%2
  GOTO Forward
)
IF "%1" == "-u" (
  set userId=%2
  GOTO Forward
)
IF "%1" == "-w" (
  set profileDir=%2
  GOTO Forward
)
IF "%1" == "-h" (
  GOTO USAGE
)

:Forward
shift /1
shift /1
GOTO Loop
:Continue


@REM #######################################################
@REM #                                                     #
@REM #  If runFile provided check the testMode             #
@REM #                                                     #
@REM #######################################################

IF NOT %runFile% == NULL (
   set testMode=9 
)



@REM #######################################################
@REM #                                                     #
@REM # Determine profile home directory                    #
@REM # Go to monitor firststep directory                   #
@REM # Set WAS environment                                 #
@REM #                                                     #
@REM #######################################################


set curDir=%~dp0

IF %profileDir% == "" cd %curDir%..\..
IF %profileDir% == "" set profileDir=%CD%

set PROFD=
for /F "delims=" %%i in ('echo "%profileDir%"') do set PROFD=%%~si
REM set W
set profileDir=%PROFD%


IF %profileType% EQU 3 (
  @REM Noprofile case
  set WAS_HOME=%profileDir%
  @REM only run IVU for noprofile
  set testMode=0
) ELSE (
  
  call "%profileDir%"\bin\setupCmdLine.bat
)

set WH=
for /F "delims=" %%i in ('echo "%WAS_HOME%"') do set WH=%%~si
REM set W
set WAS_HOME=%WH%
set IVT_WAS_HOME=%WH%
@REM #######################################################
@REM #                                                     #
@REM # Go to IVT Home                                      #
@REM #                                                     #
@REM #######################################################

IF %ivtHome% == "" (
  cd %WAS_HOME%
  cd firststeps.wbm\ivt
) ELSE (
  cd %ivtHome%
)


REM echo runDir = %runDir%
REM echo runFile = %runFile%
REM echo ivtHome = %ivtHome%
REM echo testMode = %testMode%
REM echo modelDir = %modelDir%
REM echo profileDir = %profileDir%
REM echo serverName = %serverName%
REM echo xmlFileName = %xmlFileName%
REM echo userId = %userId%
REM echo password = %password%"
REM echo tmpFile = %tmpFile%=
REM echo profileType = %profileType%

echo.
call jython -w "%WAS_HOME%"  message.jy "start.monitor.verification.test" 2>NUL
echo.



@REM #######################################################
@REM #                                                     #
@REM # Security                                            #
@REM #                                                     #
@REM #######################################################

set security=false

IF %testMode% LSS 3 GOTO WSPROFILE

FOR /F "TOKENS=1" %%a IN ('jython -w "%WAS_HOME%" lib\security.py "%profileDir%" %WAS_CELL%') do (
   set security=%%a
)


IF %security% == false GOTO WSPROFILE

IF NOT %userId% == "" GOTO WSPROFILE

set tmpCmd=userpwd.bat
set CP="%WAS_HOME%"\lib\wbminstall_util.jar
echo call "%JAVA_HOME%"\bin\java -cp %CP% com.ibm.wbm.install.util.gui.UserPassword > %tmpCmd%
FOR /F "DELIMS=: TOKENS=1-2" %%a IN ('userpwd.bat') do (
  set userId=%%a
  set password=%%b
)

del %tmpCmd%

IF "%userId%" == "" set testMode=2
IF "%password%" == "" set testMode=2

:WSPROFILE
set wsadminPropFile=%profileDir%\firststeps.wbm\ivt\wsadmin.properties.%RANDOM%
call jython -w "%WAS_HOME%" lib\wsadminproperties.py disableEchoParams "%profileDir%" "%wsadminPropFile%"



@REM #######################################################
@REM #                                                     #
@REM # If testMode equals or is greater than 3 IVT need    #
@REM # application server or deployment manager started    #
@REM #                                                     #
@REM #######################################################

set wasStarted=1
IF %testMode% GTR 2 (
  echo call jython currentTime.jy > current_time.bat
  FOR /F  %%i IN ('current_time.bat') do set checkWAS=%%i
  
  IF %profileType% EQU 2 (
    GOTO START_DMSRV
  ) ELSE (
    GOTO START_APPSRV
  )
) ELSE GOTO WSAdMIN



:START_APPSRV

IF %testMode% GTR 4 (
  GOTO STOP_APPSRV
)

@REM echo Start application server if it hasn't been started
call jython -w "%WAS_HOME%"  message.jy "start.application.server.if"
GOTO START_APPSRV2

:STOP_APPSRV

IF %security% == false (
  call "%profileDir%\bin\stopServer.bat" %serverName%  1> NUL 2>&1
) ELSE (
  call "%profileDir%\bin\stopServer.bat" %serverName% -username %userId% -password %password% 1> NUL 2>&1
)
@REM echo Start application server
call jython  -w "%WAS_HOME%" message.jy "start.application.server"

:START_APPSRV2
call "%profileDir%\bin\startServer.bat" %serverName%  1> %tmpFile% 2>&1
findstr /i "ADMU3000I ADMU3027E" %tmpFile% > NUL
IF NOT %ERRORLEVEL% == 0 (
@REM echo "Unable to start application server on %serverName%"
  call jython -w "%WAS_HOME%"  message.jy "application.server.start.failed" %serverName%
  set wasStarted=0
)
GOTO CHECKWAS

:START_DMSRV
set serverName=dmgr
@REM echo Start deploy manager if it hasn't been started
call jython -w "%WAS_HOME%" message.jy "start.deployment.manager.server.if"
call "%profileDir%\bin\startManager.bat"  1> %tmpFile% 2>&1
findstr /i "ADMU3000I ADMU3027E" %tmpFile% > NUL
IF NOT %ERRORLEVEL% == 0 (
@REM  echo Unable to start deploy manager server
  call jython "%WAS_HOME%"  message.jy "deployment.manager.server.start.failed"
  set wasStarted=0
)


:CHECKWAS
del %tmpFile%
IF %wasStarted% == 0 (
  IF NOT %runFile% == NULL (
@REM   echo Can't run the %runFile% without server started
    call jython -w "%WAS_HOME%"  message.jy "can.not.run.ivt" "%runFile%"
    exit 1
  ) ELSE (
    set checkWAS=failed
    set testMode=2
  )
)




:WSADMIN
echo.
@REM #######################################################
@REM #                                                     #
@REM # Run Install Verification Test                       #
@REM #                                                     #
@REM #######################################################

@REM #######################################################
@REM #                                                     #
@REM # Don't need connect to server if testMode is         #
@REM # less than 3                                         #
@REM #                                                     #
@REM #######################################################

set WAS_HOME=%WAS_HOME:\=\\%
set WASLIB=%WAS_HOME%\\lib
set PLUGINS=%WAS_HOME%\\plugins
set IVTLIB=%WAS_HOME%\\firststeps.wbm\\ivt\\lib
set WS_CP=%WASLIB%\\wbminstall_util.jar;%WASLIB%\\wbminstall_log.jar;%PLUGINS%\\com.ibm.wbimonitor.lifecycle.spi.jar;%IVTLIB%\\JSON4J.jar;%PLUGINS%\\com.ibm.wbimonitor.repository.jar;%PLUGINS%\\com.ibm.wbimonitor.lifecycle.jar

set profileDir=%profileDir:\=\\%

IF %testMode% LSS 3 (

  call "%profileDir%\bin\wsadmin.bat" -wsadmin_classpath "%WS_CP%" -conntype NONE -lang jython -f ivt.jy  %serverName% %checkWAS% false %testMode% "%profileDir%" %xmlFileName% %profileType% %runDir% %runFile% 

) ELSE (
  IF %security% == false (
  @REM #######################################################
  @REM #                                                     #
  @REM # Connects server without security.                   #
  @REM #                                                     #
  @REM #######################################################
    REM echo "%profileDir%\bin\wsadmin.bat" -wsadmin_classpath "%WS_CP%" -lang jython -f ivt.jy  %serverName% %checkWAS% false %testMode% "%profileDir%" %xmlFileName% %profileType% %runDir%  %runFile% %modelDir%
    call "%profileDir%\bin\wsadmin.bat" -wsadmin_classpath "%WS_CP%" -lang jython -f ivt.jy  %serverName% %checkWAS% false %testMode% "%profileDir%" %xmlFileName% %profileType% %runDir%  %runFile% %modelDir%
  ) ELSE (
  @REM #######################################################
  @REM #                                                     #
  @REM # Connects with server with user id and password      #
  @REM # provided                                            #
  @REM #                                                     #
  @REM #######################################################
    call "%profileDir%\bin\wsadmin.bat" -wsadmin_classpath "%WS_CP%" -lang jython -user %userId% -password %password% -f ivt.jy  %serverName%  %checkWAS% true %userId% %password% %testMode% "%profileDir%" %xmlFileName% %profileType% %runDir%  %runFile% %modelDir%
    REM echo "%profileDir%\bin\wsadmin.bat" -wsadmin_classpath "%WS_CP%" -lang jython -user %userId% -password %password% -f ivt.jy  %serverName% %checkWAS% true %userId% %password% %testMode% "%profileDir%" %xmlFileName% %profileType% %runDir%  %runFile% %modelDir%
  )
)



call move  "%wsadminPropFile%"  "%profileDir%"\properties\wsadmin.properties 2>NUL >NUL

@REM
@REM Other tests (not through wsadmin)
@REM

:DONE
@REM echo "Done"
endlocal
