#!/bin/sh

#############################################################################
#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2007,2009. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################

#echo ""
#echo "Start Monitor Verification Test"
#echo ""

#######################################################
#                                                     #
# Subroutine: Usage                                   #
#                                                     #
#######################################################

usage () {
  echo ""
  echo "ivt.sh -c <component directory> -d <ivt directory> -f <testcase file> "
  echo "       -m <test mode> -n <model directory> -o <output xml> -p <password>"
  echo "       -s <server name> -t <profile type> -u <user name>"
  echo "       -w <profile directory> -z <SOAP port>"
  echo ""
  echo "where:  "
  echo ""
  echo "  -c <component directory> : "
  echo "     which component to run under ivt. If not selected all components "
  echo "     will be included."
  echo ""
  echo "  -d <ivt directory> :" 
  echo "     ivt home directory. By default it is <WAS_HOME>/firststeps.wbm/ivt "
  echo ""
  echo "  -f <testcase file> :" 
  echo "     which testcase to run under selected component. If not selected all"
  echo "     testcase files will be run"
  echo ""
  echo "  -m <test mode> :" 
  echo "     test mode: 0-9. For selected testcase files only last number in file"
  echo "     name equals or above test mode will run. 0: IVU only; 9: run all tests"
  echo ""
  echo "  -n  <model directory> :"
  echo "      directory relative to <WAS_HOME>/firststeps.wbm/ivt/samples where the"
  echo "      files for a specific model install are located."
  echo ""
  echo "  -o <output xml> :"
  echo "     output file name for xml format: by default test result only goes to stdout."
  echo ""
  echo "  -s <server name> : WAS server name. default server1"
  echo ""
  echo "  -u <user name> : WAS user id"
  echo ""
  echo "  -p <password> : WAS user password "
  echo ""
  echo "  -t <profile type> :"
  echo "     profile type. 1: application server, 2: deployment manager"
  echo "                   3: none, 4: custom, 5: federated"
  echo ""
  echo "  -w <profile directory> :"
  echo "     WAS profile directory. If not provided will assume ../.. "
  echo ""
  exit
  
}

#######################################################
#                                                     #
# Variables                                           #
#                                                     #
#######################################################
runDir="."
runFile="NULL"
ivtHome=""
testMode=5
modelDir="NULL"
profileDir=""
serverName="server1"
xmlFileName="NULL"
userId=""
password=""
tmpFile=ivt_$$
profileType=1
portChanged=0
checkWAS="false"

#######################################################
#                                                     #
# Read command line options                           #
#                                                     #
#######################################################

while getopts ":c:d:f:m:o:p:s:t:u:w:" opt
do
  case $opt in
    c) runDir=$OPTARG;;
    d) ivtHome=$OPTARG;;
    f) runFile=$OPTARG;;
    m) testMode=$OPTARG;;
    n) modelMode=$OPTARG;;
    o) xmlFileName=$OPTARG;;
    p) password=$OPTARG;;
    s) serverName=$OPTARG;;
    t) profileType=$OPTARG;;
    u) userId=$OPTARG;;
    w) profileDir=$OPTARG;;
    ?) usage
  esac
done


#######################################################
#                                                     #
# If runFile provide check the testMode               #
#                                                     #
#######################################################
if [ "$runFile" != "NULL" ]; then
  testMode=9
  #testMode=`echo $runFile | sed 's/^.*\([0-9]\)\.[^\.]\+$/\1/g'`
  #if [ -z $testMode ]; then
  #  echo "Can't parse $runFile to get testMode"
  #  exit
  #fi
fi



#######################################################
#                                                     #
# Determine profile home directory                    #
# Go to monitor firststep directory                   #
# Set WAS environment                                 #
#                                                     #
#######################################################


if [ -z "$profileDir" ]; then
  curDir=`dirname ${0}`
  cd $curDir/../..
  profileDir=`pwd`
fi

#for noprofile case
if [ $profileType -eq  3 ]; then
  WAS_HOME=$profileDir
  #Only run IVU for noprofile
  testMode=0
else 
  . $profileDir/bin/setupCmdLine.sh 
fi

#######################################################
#                                                     #
# Go to IVT home                                      #
#                                                     #
#######################################################
if [ -z "$ivtHome" ]; then
  cd ${WAS_HOME}
  cd firststeps.wbm/ivt
else
  cd ${ivtHome}
fi

echo ""
./jython.sh -w ${WAS_HOME}  message.jy "start.monitor.verification.test" 2>/dev/null
echo ""

#######################################################
#                                                     #
# Security                                            #
#                                                     #
#######################################################

#work around JVM bug on AIX
LIBPATH=
export LIBPATH

security="false"
if [ $testMode -gt 2 ]; then
  security=`./jython.sh -w $WAS_HOME lib/security.py $profileDir $WAS_CELL`

  #echo "security: $security"
  if [ "$security" = "true" ]; then
    if [ -z "$userId" ]; then
      CP=${WAS_HOME}/lib/wbminstall_util.jar
      userpwd=`${JAVA_HOME}/bin/java -cp $CP com.ibm.wbm.install.util.gui.UserPassword` 
      userId=`echo $userpwd | awk 'BEGIN {FS=":"}{print $1}'`
      password=`echo $userpwd | awk 'BEGIN {FS=":"}{print $2}'`
    fi
    [ -z "$userId" ] && testMode=2 
    [ -z "$password" ] && testMode=2 
  fi
fi

wsadminPropFile=${profileDir}/firststeps.wbm/ivt/wsadmin.properties.tmp
./jython.sh -w $WAS_HOME lib/wsadminproperties.py "disableEchoParams" $profileDir $wsadminPropFile


#######################################################
#                                                     #
# If testMode equals or is greater than 3 IVT need    #
# application server or deployment manager started    #
#                                                     #
#######################################################
wasStarted=1
if [ $testMode -gt 2 ]; then

  checkWAS=`./jython.sh currentTime.jy`
  if [ $profileType -ne 2 ]; then
    if [ $testMode -gt 4 ]; then
      if [ "$security" = "true" ]; then
        $profileDir/bin/stopServer.sh $serverName -username $userId -password $password  > /dev/null 2>&1
      else
        $profileDir/bin/stopServer.sh $serverName  > /dev/null 2>&1
      fi
      #echo "Start application server"
      ./jython.sh -w ${WAS_HOME} message.jy "start.application.server"
    else
      #echo "Start application server if it hasn't been started"
      ./jython.sh -w ${WAS_HOME} message.jy "start.application.server.if"
    fi
    $profileDir/bin/startServer.sh $serverName > $tmpFile 2>&1
    cat $tmpFile | grep "ADMU3027" >/dev/null  2>&1
    #test $? = 0 &&  echo "application server already started on $serverName"
    test $? = 0 &&  ./jython.sh -w ${WAS_HOME} message.jy "application.server.already.started" $serverName
    cat $tmpFile | grep "ADMU3000I" >/dev/null 2>&1 || cat $tmpFile | grep "ADMU3027" >/dev/null 2>&1
    test $? != 0 && {
      #echo "Unable to start application server on $serverName"
      ./jython.sh -w ${WAS_HOME}  message.jy "application.server.start.failed" $serverName
      wasStarted=0
    }
    rm -rf $tmpFile
  else
    serverName=dmgr
    #echo "Start deploy manager if it hasn't been started"
    ./jython.sh -w ${WAS_HOME} message.jy "start.deployment.manager.server.if"
    $profileDir/bin/startManager.sh  > $tmpFile

    cat $tmpFile | grep "ADMU3027" >/dev/null 2>&1 
    #test $? = 0 &&  echo "manager server already started"
    test $? = 0 &&  ./jython.sh -w ${WAS_HOME}  message.jy "deployment.manager.server.already.started"
    cat $tmpFile | grep "ADMU3000I" >/dev/null 2>&1 || cat $tmpFile | grep "ADMU3027" >/dev/null 2>&1
    test $? != 0 && {
      #echo "Unable to start deploy manager server"
      ./jython.sh -w ${WAS_HOME} message.jy "deployment.manager.server.start.failed"
      wasStarted=0
    }
    rm -rf $tmpFile
  fi
  if [ $wasStarted -ne 1 ]; then
    if [ ! "$runFile" = "NULL" ]; then
      #echo "Can't run the $runFile without server started"
      ./jython.sh -w ${WAS_HOME}  message.jy "can.not.run.ivt" "$runFile"
      exit
    else
      if [ $testMode -gt 2 ]; then
        checkWAS="failed"
        testMode=2
      fi
    fi
  fi
fi





#######################################################
#                                                     #
# Run Install Verification Test                       #
#                                                     #
#######################################################

echo ""

#######################################################
#                                                     #
# Don't need connect to server if testMode is         #
# less than 3                                         #
#                                                     #
#######################################################

WASLIB=${WAS_HOME}/lib
PLUGINS=${WAS_HOME}/plugins
IVTLIB=${WAS_HOME}/firststeps.wbm/ivt/lib
WS_CP=${WASLIB}/wbminstall_util.jar:${WASLIB}/wbminstall_log.jar:${PLUGINS}/com.ibm.wbimonitor.lifecycle.spi.jar:${IVTLIB}/JSON4J.jar:${PLUGINS}/com.ibm.wbimonitor.repository.jar:${PLUGINS}/com.ibm.wbimonitor.lifecycle.jar

#work around JVM bug on AIX
LIBPATH=
export LIBPATH

if [ $testMode -lt 3 ]; then
  $profileDir/bin/wsadmin.sh -wsadmin_classpath $WS_CP -conntype NONE -lang jython \
      -f ivt.jy $serverName $checkWAS "false" $testMode  $profileDir $xmlFileName $profileType \
      $runDir $runFile 
  
else
  if [ "$security" = "true" ]; then
  #######################################################
  #                                                     #
  # Connects with server with user id and password      #
  # provided                                            #
  #                                                     #
  #######################################################
  $profileDir/bin/wsadmin.sh -wsadmin_classpath $WS_CP -user $userId -password $password \
      -lang jython -f ivt.jy $serverName $checkWAS "true" $userId $password $testMode \
      $profileDir  $xmlFileName $profileType $runDir $runFile $modelDir
  else
  #######################################################
  #                                                     #
  # Connects with server without security               #
  #                                                     #
  #######################################################
  $profileDir/bin/wsadmin.sh -wsadmin_classpath $WS_CP -lang jython \
      -f ivt.jy $serverName $checkWAS "false" $testMode  $profileDir $xmlFileName $profileType  \
      $runDir $runFile $modelDir
  fi
fi


mv $wsadminPropFile ${profileDir}/properties/wsadmin.properties 


#######################################################
#                                                     #
# Other tests (not through wsadmin)                   #
#                                                     #
#######################################################


echo ""
#echo "Done"
