# **********************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24 
# 
#  (c) Copyright IBM Corp. 2007, 2008.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# **********************************************************************

# Originally from Ke Feng Shao
# Created: 09/21/2006
# Modified: 06/09/2007

from java.lang import System
lineSeparator = System.getProperty("line.separator")
from ivtout import outputResult
from com.ibm.wbmonitor.install.common.log import ILogger
import re

#__all__ = ["CheckResource"]


class CheckResource:

  className = "CheckResource"

  def __init__(self, aa, ac, log, resolver):
    self.AdminConfig = ac
    self.AdminApp = aa
    self.logger   = log
    self.mesgResolver = resolver
    self.passed = self.mesgResolver.getMessage('passed')
    self.failed = self.mesgResolver.getMessage('failed')


  # Function: Verfiy whether specified WAS resources are installed
  # Parameters:  resource - type of resource, like 'DataSource'
  #              attribute - attribute of 'resource' which will be 
  #                          verified, like 'name'
  #              expectedList - 'attribute' values of expected 'resource' list
  def checkInstalledResource(self,resource,attribute,expectedList):

    errorCount = 0
    methodName = "checkInstalledResource"
    resList = self.AdminConfig.list(resource)
    if (len(resList) == 0):
      mesg = resource + " is not installed"
      outputResult("item", resource, {'status':self.failed})
      self.logger.msg(ILogger.TYPE_INFO, CheckResource.className, 
			methodName, mesg)
      errorCount += 1
      return errorCount

    resArray =  resList.split(lineSeparator)
    resNameArray = []

    for res in resArray:
      resName = self.AdminConfig.showAttribute(res,attribute) 
      resNameArray.append(resName) 

    p = re.compile('jdbc/com.ibm.ws.sib/')
    for res in expectedList:
      if (attribute == 'jndiName'):
        displayName = p.sub('', res)
      else:
        displayName = res

      if (res in resNameArray):
        mesg = res + " is installed"
        outputResult("item", displayName, {'status':self.passed})
	self.logger.msg(ILogger.TYPE_INFO, CheckResource.className, 
			methodName, mesg)
      else:
        mesg = res + " isn't installed"
        outputResult("item", displayName, {'status':self.failed})
	self.logger.msg(ILogger.TYPE_WARN, CheckResource.className, 
			methodName, mesg)
        errorCount += 1
    return errorCount


  # Function: Verfiy whether specified applications are installed
  # Parameters:  expectedList - application names expected to install
  def checkApplications(self, expectedList):
    errorCount = 0
    methodName = "checkApplications"
    appList = self.AdminApp.list()
    appArray =  appList.split(lineSeparator)

    for app in expectedList:
      isExist = 0
      for appTemp in appArray:	
        if (appTemp.startswith(app)):
  	  isExist = 1
	  break
      if (isExist):
        mesg = app + " is installed"
        outputResult("item", app, {'status':self.passed})
	self.logger.msg(ILogger.TYPE_INFO, CheckResource.className, 
			methodName, mesg)
      else:
        mesg =  app + " isn't installed"
        outputResult("item", app, {'status':self.failed})
	self.logger.msg(ILogger.TYPE_WARN, CheckResource.className, 
			methodName, mesg)
        errorCount += 1
    return errorCount

  # Function: Verfiy whether specified applications are installed
  # Parameters:  expectedList - application names expected to install
  #              flag - "any" or "all"
  def applicationsExist(self, expectedList, flag):
    methodName = "applicationsExist"
    appList = self.AdminApp.list()
    appArray =  appList.split(lineSeparator)

    numFound = 0
    for app in expectedList:
      for appTemp in appArray:	
        if (appTemp.startswith(app)):
          numFound += 1
          if ((flag == "any") or (numFound == len(expectedList))):
  	    return 1
	  break
   
    if (numFound == len(expectedList)):
      return 1

    return 0

  # Function: getVariables
  # Parameter: type: cell, node
  def getVariables(self, type):

    mn = "getVariables"

    formatLength = 4   
    if (type.lower() == "cell"):
      formatLength = 2   

    varMapList = self.AdminConfig.list("VariableMap")
    varMapArray =  varMapList.split(lineSeparator)

    #Search all Node Environment Variables 
    for varMap in varMapArray:
      temp = varMap.split("/")
      if (len(temp) == formatLength):
	break

    varList = self.AdminConfig.showAttribute(varMap,"entries")
    varArray = varList.split(" ")
    varNum = len(varArray)
    temp = varArray[0]
    varArray[0] = temp[1:]
    temp = varArray[varNum-1]
    varArray[varNum-1] = temp[0:len(temp)-1]

    varDir = {} 
    for var in varArray:
      name = self.AdminConfig.showAttribute(var,"symbolicName") 
      value = self.AdminConfig.showAttribute(var,"value") 
      varDir[name] = value

    
    return varDir


  # Function: Verfiy whether specified Environment Variables are installed
  # Parameters:  expectedList - Environment Variables expected to install, 
  #                             the format should be like {"WBMONITOR_NODE":"Node01",...}
  #              type: cell, node, both
  def checkEnvironmentVariables(self, expectedDir, type):

    errorCount = 0
    mn = "checkEnvironmentVariables"

    
    if (type.lower() == "cell"):
      varDir = self.getVariables("cell")
      errorCount = self.checkVariables(varDir, expectedDir, "cell")
    elif (type.lower() == "node"):
      varDir = self.getVariables("node")
      errorCount = self.checkVariables(varDir, expectedDir, "node")
    else: #both
      varDir = self.getVariables("cell")
      errorCount = self.checkVariables(varDir, expectedDir, "cell")
      varDir = self.getVariables("node")
      errorCount = self.checkVariables(varDir, expectedDir, "node")

    return errorCount


  # Function: Verfiy whether specified Environment Variables are installed
  # Parameters:varDir - variables dictionary  
  #            expectedList - Environment Variables expected to install, 
  #                             the format should be like {"WBMONITOR_NODE":"Node01",...}
  #              type: cell, node
  def checkVariables(self, varDir, expectedDir, type):

    errorCount = 0
    mn = "checktVariables"

    #Verify expected Environment Variables 
    for var in expectedDir:
      if (varDir.has_key(var)):
	if (expectedDir[var].lower() == varDir[var].lower()):
          mesg = var + " of " + type + "  is defined"
          outputResult("item", var + " of " + type , {'status':self.passed})
          self.logger.msg(ILogger.TYPE_INFO, CheckResource.className, mn, mesg)
        else:
	  mesg = var + " of " + type + "  has wrong value. Expects: " \
			  + expectedDir[var] + " but get " + varDir[key]
          outputResult("item", var + " of " + type , {'status':self.failed})
          self.logger.msg(ILogger.TYPE_WARN, CheckResource.className, mn, mesg)
          errorCount += 1
      else:
        mesg =  var + " of " + type + "is not defined"
        outputResult("item", var + " of " + type, {'status':self.failed})
        self.logger.msg(ILogger.TYPE_WARN, CheckResource.className, mn, mesg)
        errorCount += 1

    return errorCount



  # Function: Verfiy whether specified Environment Variable names are installed
  # Parameters:  
  #   expectedList - Environment Variable names expected to install 
  #                  the format should be like ["WBMONITOR_NODE", ...]
  #   type: cell, node or both
  #
  def checkEnvironmentVariableNames(self, expectedList, type):

    errorCount = 0
    mn = "checkEnvironmentVariableNames"

    if (type.lower() == "cell"):
      varDir = self.getVariables("cell")
      errorCount = self.checkVariableNames(varDir, expectedList, "cell")
    elif (type.lower() == "node"):
      varDir = self.getVariables("node")
      errorCount = self.checkVariableNames(varDir, expectedList, "node")
    else: #both
      varDir = self.getVariables("cell")
      errorCount = self.checkVariableNames(varDir, expectedList, "cell")
      varDir = self.getVariables("node")
      errorCount += self.checkVariableNames(varDir, expectedList, "node")

    return errorCount


  # Function: Verfiy whether specified Environment Variable names are installed
  # Parameters: 
  #   varDir - variables dictionary  
  #   expectedList - Environment Variable names expected to install 
  #                  the format should be like ["WBMONITOR_NODE", ...]
  #   type: cell, node
  #
  def checkVariableNames(self, varDir, expectedList, type):

    errorCount = 0 
    mn = "checkVariableNames"
    #Verify expected Environment Variables 
    for var in expectedList:
      if (varDir.has_key(var)):
        mesg = var + " of " + type + "  is defined"
        outputResult("item", var + " of " + type , {'status':self.passed})
        self.logger.msg(ILogger.TYPE_INFO, CheckResource.className, mn, mesg)
      else:
        mesg =  var + " of " + type + "is not defined"
        outputResult("item", var + " of " + type, {'status':self.failed})
        self.logger.msg(ILogger.TYPE_WARN, CheckResource.className, mn, mesg)
        errorCount += 1

    return errorCount



